@@ -37,10 +37,6 @@
 
 #include "ui_certificatedetailsdialog.h"
 
-#include <models/useridlistmodel.h>
-#include <models/subkeylistmodel.h>
-#include <models/keycache.h>
-
 #include <commands/changepassphrasecommand.h>
 #include <commands/changeownertrustcommand.h>
 #include <commands/changeexpirycommand.h>
@@ -48,14 +44,17 @@
 #include <commands/certifycertificatecommand.h>
 #include <commands/dumpcertificatecommand.h>
 
-#include <utils/formatting.h>
 #include <utils/gnupg-helper.h>
 
-#include <Libkleo/CryptoBackendFactory>
-#include <Libkleo/CryptoBackend>
-#include <Libkleo/KeyListJob>
+#include <Libkleo/UserIDListModel>
+#include <Libkleo/SubkeyListModel>
+#include <Libkleo/KeyCache>
+#include <Libkleo/Formatting>
 #include <Libkleo/Dn>
 
+#include <QGpgME/Protocol>
+#include <QGpgME/KeyListJob>
+
 #include <gpgme++/key.h>
 #include <gpgme++/keylistresult.h>
 
@@ -67,8 +66,6 @@
 #include <QPointer>
 #include <QHeaderView>
 
-#include <boost/mem_fn.hpp>
-
 #include <algorithm>
 #include <cassert>
 #include <KSharedConfig>
@@ -78,11 +75,10 @@ using namespace Kleo;
 using namespace Kleo::Dialogs;
 using namespace Kleo::Commands;
 using namespace GpgME;
-using namespace boost;
 
 static bool own(const QVector<UserID::Signature> &sigs)
 {
-    const shared_ptr<const KeyCache> kc = KeyCache::instance();
+    const std::shared_ptr<const KeyCache> kc = KeyCache::instance();
     Q_FOREACH (const UserID::Signature &sig, sigs) {
         const Key signer = kc->findByKeyIDOrFingerprint(sig.signerKeyID());
         if (signer.isNull() || !signer.hasSecret()) {
@@ -245,11 +241,11 @@ private:
         if (keyListJob) {
             return;
         }
-        const CryptoBackend::Protocol *const protocol = CryptoBackendFactory::instance()->protocol(key.protocol());
+        const QGpgME::Protocol *const protocol = (key.protocol() == GpgME::OpenPGP) ? QGpgME::openpgp() : QGpgME::smime();
         if (!protocol) {
             return;
         }
-        KeyListJob *const job = protocol->keyListJob(/*remote*/false, /*includeSigs*/true, /*validate*/true);
+        QGpgME::KeyListJob *const job = protocol->keyListJob(/*remote*/false, /*includeSigs*/true, /*validate*/true);
         if (!job) {
             return;
         }
@@ -464,7 +460,7 @@ private:
 
     QPointer<DumpCertificateCommand> dumpCertificateCommand;
 
-    QPointer<KeyListJob> keyListJob;
+    QPointer<QGpgME::KeyListJob> keyListJob;
 
     struct UI : public Ui_CertificateDetailsDialog {
         explicit UI(Dialogs::CertificateDetailsDialog *qq)
