@@ -37,8 +37,8 @@
 #include <view/searchbar.h>
 #include <view/tabwidget.h>
 
-#include <models/keylistmodel.h>
-#include <models/keycache.h>
+#include <Libkleo/KeyListModel>
+#include <Libkleo/KeyCache>
 
 #include <commands/reloadkeyscommand.h>
 #include <commands/lookupcertificatescommand.h>
@@ -58,14 +58,12 @@
 #include <QPointer>
 #include <QVBoxLayout>
 
-#include <boost/bind.hpp>
-
 #include <algorithm>
+#include <cassert>
 
 using namespace Kleo;
 using namespace Kleo::Dialogs;
 using namespace Kleo::Commands;
-using namespace boost;
 using namespace GpgME;
 
 class CertificateSelectionDialog::Private
@@ -107,7 +105,6 @@ private:
     {
         return !keys.empty();
     }
-    void filterAllowedKeys(std::vector<Key> &keys);
     void updateLabelText()
     {
         ui.label.setText(!customLabelText.isEmpty() ? customLabelText :
@@ -232,7 +229,7 @@ void CertificateSelectionDialog::setStringFilter(const QString &filter)
     d->ui.tabWidget.setStringFilter(filter);
 }
 
-void CertificateSelectionDialog::setKeyFilter(const shared_ptr<KeyFilter> &filter)
+void CertificateSelectionDialog::setKeyFilter(const std::shared_ptr<KeyFilter> &filter)
 {
     d->ui.tabWidget.setKeyFilter(filter);
 }
@@ -243,7 +240,7 @@ void CertificateSelectionDialog::selectCertificates(const std::vector<Key> &keys
     if (!view) {
         return;
     }
-    const KeyListModelInterface *const model = dynamic_cast<KeyListModelInterface *>(view->model());
+    const auto *const model = d->ui.tabWidget.currentModel();
     assert(model);
     QItemSelectionModel *const sm = view->selectionModel();
     assert(sm);
@@ -265,7 +262,7 @@ std::vector<Key> CertificateSelectionDialog::selectedCertificates() const
     if (!view) {
         return std::vector<Key>();
     }
-    const KeyListModelInterface *const model = dynamic_cast<KeyListModelInterface *>(view->model());
+    const auto *const model = d->ui.tabWidget.currentModel();
     assert(model);
     const QItemSelectionModel *const sm = view->selectionModel();
     assert(sm);
@@ -291,7 +288,7 @@ void CertificateSelectionDialog::Private::slotKeysMayHaveChanged()
 {
     q->setEnabled(true);
     std::vector<Key> keys = (options & SecretKeys) ? KeyCache::instance()->secretKeys() : KeyCache::instance()->keys();
-    filterAllowedKeys(keys);
+    q->filterAllowedKeys(keys, options);
     const std::vector<Key> selected = q->selectedCertificates();
     if (AbstractKeyListModel *const model = ui.tabWidget.flatModel()) {
         model->setKeys(keys);
@@ -302,16 +299,16 @@ void CertificateSelectionDialog::Private::slotKeysMayHaveChanged()
     q->selectCertificates(selected);
 }
 
-void CertificateSelectionDialog::Private::filterAllowedKeys(std::vector<Key> &keys)
+void CertificateSelectionDialog::filterAllowedKeys(std::vector<Key> &keys, int options)
 {
     std::vector<Key>::iterator end = keys.end();
 
     switch (options & AnyFormat) {
     case OpenPGPFormat:
-        end = std::remove_if(keys.begin(), end, boost::bind(&Key::protocol, _1) != GpgME::OpenPGP);
+        end = std::remove_if(keys.begin(), end, [](const Key &key) { return key.protocol() != OpenPGP; });
         break;
     case CMSFormat:
-        end = std::remove_if(keys.begin(), end, boost::bind(&Key::protocol, _1) != GpgME::CMS);
+        end = std::remove_if(keys.begin(), end, [](const Key &key) { return key.protocol() != CMS; });
         break;
     default:
     case AnyFormat:
@@ -320,10 +317,10 @@ void CertificateSelectionDialog::Private::filterAllowedKeys(std::vector<Key> &ke
 
     switch (options & AnyCertificate) {
     case SignOnly:
-        end = std::remove_if(keys.begin(), end, !boost::bind(&Key::canReallySign, _1));
+        end = std::remove_if(keys.begin(), end, [](const Key &key) { return !key.canReallySign(); });
         break;
     case EncryptOnly:
-        end = std::remove_if(keys.begin(), end, !boost::bind(&Key::canEncrypt, _1));
+        end = std::remove_if(keys.begin(), end, [](const Key &key) { return !key.canEncrypt(); });
         break;
     default:
     case AnyCertificate:
@@ -331,7 +328,7 @@ void CertificateSelectionDialog::Private::filterAllowedKeys(std::vector<Key> &ke
     }
 
     if (options & SecretKeys) {
-        end = std::remove_if(keys.begin(), end, !boost::bind(&Key::hasSecret, _1));
+        end = std::remove_if(keys.begin(), end, [](const Key &key) { return !key.hasSecret(); });
     }
 
     keys.erase(end, keys.end());
@@ -368,7 +365,7 @@ void CertificateSelectionDialog::Private::slotDoubleClicked(const QModelIndex &i
 {
     QAbstractItemView *const view = ui.tabWidget.currentView();
     assert(view);
-    const KeyListModelInterface *const model = dynamic_cast<KeyListModelInterface *>(view->model());
+    const auto *const model = ui.tabWidget.currentModel();
     assert(model);
     Q_UNUSED(model);
     QItemSelectionModel *const sm = view->selectionModel();
