@@ -35,9 +35,6 @@
 #include "mainwindow.h"
 #include "aboutdata.h"
 
-#include "models/keylistmodel.h"
-#include "models/keylistsortfilterproxymodel.h"
-
 #include "view/searchbar.h"
 #include "view/tabwidget.h"
 #include "view/keylistcontroller.h"
@@ -52,7 +49,6 @@
 #include "utils/detail_p.h"
 #include "utils/gnupg-helper.h"
 #include "utils/action_data.h"
-#include "utils/classify.h"
 #include "utils/filedialog.h"
 #include "utils/clipboardmenu.h"
 
@@ -82,20 +78,19 @@
 #include <QVBoxLayout>
 #include <QMimeData>
 
-#include <Libkleo/CryptoBackendFactory>
+#include <Libkleo/KeyListModel>
+#include <Libkleo/KeyListSortFilterProxyModel>
 #include <libkleo/cryptoconfigdialog.h>
-#include <Libkleo/CryptoConfig>
 #include <Libkleo/Stl_Util>
-
-#include <boost/bind.hpp>
-#include <boost/shared_ptr.hpp>
+#include <Libkleo/Classify>
+#include <QGpgME/CryptoConfig>
+#include <QGpgME/Protocol>
 
 #include <vector>
 #include <KSharedConfig>
 
 using namespace Kleo;
 using namespace Kleo::Commands;
-using namespace boost;
 using namespace GpgME;
 
 static KGuiItem KStandardGuiItem_quit()
@@ -367,7 +362,7 @@ void MainWindow::Private::setupActions()
 
 void MainWindow::Private::configureBackend()
 {
-    Kleo::CryptoConfig *const config = Kleo::CryptoBackendFactory::instance()->config();
+    QGpgME::CryptoConfig *const config = QGpgME::cryptoConfig();
     if (!config) {
         KMessageBox::error(q, i18n("Could not configure the cryptography backend (gpgconf tool not found)"), i18n("Configuration Error"));
         return;
@@ -476,9 +471,9 @@ static QStringList extract_local_files(const QMimeData *data)
     QStringList result;
     std::transform(urls.begin(), end,
                    std::back_inserter(result),
-                   boost::bind(&QUrl::toLocalFile, _1));
+                   std::mem_fn(&QUrl::toLocalFile));
     result.erase(std::remove_if(result.begin(), result.end(),
-                                boost::bind(&QString::isEmpty, _1)), result.end());
+                                std::mem_fn(&QString::isEmpty)), result.end());
     return result;
 }
 
