@@ -37,17 +37,16 @@
 #include <crypto/decryptverifytask.h>
 #include <crypto/decryptverifyemailcontroller.h>
 
-#include <utils/formatting.h>
-
-#include <models/keycache.h>
-
 #include <utils/hex.h>
 #include <utils/input.h>
 #include <utils/output.h>
 #include <utils/kleo_assert.h>
 
 #include <Libkleo/Exception>
-#include <Libkleo/CryptoBackendFactory>
+#include <Libkleo/KeyCache>
+#include <Libkleo/Formatting>
+
+#include <QGpgME/Protocol>
 
 #include <gpgme++/error.h>
 #include <gpgme++/key.h>
@@ -63,7 +62,6 @@ using namespace Kleo;
 using namespace Kleo::Crypto;
 using namespace Kleo::Formatting;
 using namespace GpgME;
-using namespace boost;
 
 class DecryptVerifyCommandEMailBase::Private : public QObject
 {
@@ -99,7 +97,7 @@ public Q_SLOTS:
 public:
 
 private:
-    shared_ptr<DecryptVerifyEMailController> controller;
+    std::shared_ptr<DecryptVerifyEMailController> controller;
 };
 
 DecryptVerifyCommandEMailBase::DecryptVerifyCommandEMailBase()
@@ -119,7 +117,7 @@ int DecryptVerifyCommandEMailBase::doStart()
 
     const QString st = sessionTitle();
     if (!st.isEmpty())
-        Q_FOREACH (const shared_ptr<Input> &i, inputs()) {
+        Q_FOREACH (const std::shared_ptr<Input> &i, inputs()) {
             i->setLabel(st);
         }
 
@@ -201,7 +199,7 @@ void DecryptVerifyCommandEMailBase::Private::checkForErrors() const
 
     kleo_assert(proto != UnknownProtocol);
 
-    const CryptoBackend::Protocol *const backend = CryptoBackendFactory::instance()->protocol(proto);
+    const auto backend = (proto == GpgME::OpenPGP) ? QGpgME::openpgp() : QGpgME::smime();
     if (!backend)
         throw Kleo::Exception(q->makeError(GPG_ERR_UNSUPPORTED_PROTOCOL),
                               proto == OpenPGP ? i18n("No backend support for OpenPGP") :
